injectCSSCode method

  1. @override
Future<void> injectCSSCode({
  1. required String source,
})

{@template tmpflutter_webview_platform_interface.PlatformInAppWebViewController.injectCSSCode} Injects CSS into the WebView.

NOTE: This method shouldn't be called in the PlatformWebViewCreationParams.onWebViewCreated or PlatformWebViewCreationParams.onLoadStart events, because, in these events, the WebView is not ready to handle it yet. Instead, you should call this method, for example, inside the PlatformWebViewCreationParams.onLoadStop event or in any other events where you know the page is ready "enough".

NOTE for Web: this method will have effect only if the iframe has the same origin.

Officially Supported Platforms/Implementations:

  • Android native WebView
  • iOS
  • MacOS
  • Web @{endtemplate}

Implementation

@override
Future<void> injectCSSCode({required String source}) async {
  Map<String, dynamic> args = <String, dynamic>{};
  args.putIfAbsent('source', () => source);
  await channel?.invokeMethod('injectCSSCode', args);
}